==> mfc-vms-meta-model-0.1.0-sources.jar: com/valor/mfc/vms/meta/model/database/ddo/playlist/award/AbstractAwardMedia.java <==
package com.valor.mfc.vms.meta.model.database.ddo.playlist.award;

import com.valor.mfc.vms.meta.model.database.ddo.media.base.AbstractId;
import com.valor.mfc.vms.meta.model.database.constants.EAwardCategory;
import com.valor.mfc.vms.meta.model.database.constants.EAwardEvent;
import com.valor.mfc.vms.meta.model.database.constants.EAwardGot;
import com.valor.mfc.vms.api.model.constant.EVideoType;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.MappedSuperclass;

/**
 * Created by Frank.Huang on 2016/6/15.
 */
@MappedSuperclass
public class AbstractAwardMedia extends AbstractId {
    @Id
    @Column(name = "pid")
    protected Long pid;

    @Column(name = "year")
    protected int year= -1;

    @Column(name = "event")
    protected EAwardEvent event;

    @Column(name = "category")
    protected EAwardCategory category;

    @Column(name = "won_or_nominated")
    protected EAwardGot wonOrNominated;

    @Column(name = "media_type")
    protected EVideoType mediaType;

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public int getYear() {
        return year;
    }

    public void setYear(int year) {
        this.year = year;
    }

    public EAwardEvent getEvent() {
        return event;
    }

    public void setEvent(EAwardEvent event) {
        this.event = event;
    }

    public EAwardCategory getCategory() {
        return category;
    }

    public void setCategory(EAwardCategory category) {
        this.category = category;
    }

    public EAwardGot getWonOrNominated() {
        return wonOrNominated;
    }

    public void setWonOrNominated(EAwardGot wonOrNominated) {
        this.wonOrNominated = wonOrNominated;
    }

    public EVideoType getMediaType() {
        return mediaType;
    }

    public void setMediaType(EVideoType mediaType) {
        this.mediaType = mediaType;
    }
}

==> mfc-vms-meta-model-0.1.11-sources.jar: com/valor/mfc/vms/meta/model/database/ddo/playlist/award/AbstractAwardMedia.java <==
package com.valor.mfc.vms.meta.model.database.ddo.playlist.award;

import com.valor.mfc.vms.api.model.constant.EVideoType;
import com.valor.mfc.vms.meta.model.database.constants.EAwardGot;
import com.valor.mfc.vms.meta.model.database.ddo.media.base.AbstractId;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.MappedSuperclass;

/**
 * Created by Frank.Huang on 2016/6/15.
 */
@MappedSuperclass
public class AbstractAwardMedia extends AbstractId {
    @Id
    @Column(name = "pid")
    protected Long pid;

    @Column(name = "year")
    protected int year= -1;

    @Column(name = "event")
    protected int event;

    @Column(name = "category")
    protected int category;

    @Column(name = "won_or_nominated")
    protected EAwardGot wonOrNominated;

    @Column(name = "media_type")
    protected EVideoType mediaType;

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public int getYear() {
        return year;
    }

    public void setYear(int year) {
        this.year = year;
    }

    public int getEvent() {
        return event;
    }

    public void setEvent(int event) {
        this.event = event;
    }

    public int getCategory() {
        return category;
    }

    public void setCategory(int category) {
        this.category = category;
    }

    public EAwardGot getWonOrNominated() {
        return wonOrNominated;
    }

    public void setWonOrNominated(EAwardGot wonOrNominated) {
        this.wonOrNominated = wonOrNominated;
    }

    public EVideoType getMediaType() {
        return mediaType;
    }

    public void setMediaType(EVideoType mediaType) {
        this.mediaType = mediaType;
    }
}
